@@ -4,8 +4,11 @@ from unittest.mock import ANY
 import pytest
 
 from pdm.cli import actions
+from pdm.models.backends import get_backend
 from pdm.models.python import PythonInfo
 
+PYTHON_VERSION = f"{sys.version_info[0]}.{sys.version_info[1]}"
+
 
 def test_init_validate_python_requires(project_no_init):
     with pytest.raises(ValueError):
@@ -29,6 +32,7 @@ def test_init_command(project_no_init, invoke, mocker):
         author="Testing",
         email="me@example.org",
         python_requires=f">={python_version}",
+        build_backend=None,
         hooks=ANY,
     )
 
@@ -41,7 +45,7 @@ def test_init_command_library(project_no_init, invoke, mocker):
     do_init = mocker.patch.object(actions, "do_init")
     result = invoke(
         ["init"],
-        input="\ny\ntest-project\n\nTest Project\n\n\n\n\n",
+        input="\ny\ntest-project\n\nTest Project\n1\n\n\n\n\n",
         obj=project_no_init,
     )
     assert result.exit_code == 0
@@ -55,6 +59,7 @@ def test_init_command_library(project_no_init, invoke, mocker):
         author="Testing",
         email="me@example.org",
         python_requires=f">={python_version}",
+        build_backend=get_backend("setuptools"),
         hooks=ANY,
     )
 
@@ -88,6 +93,7 @@ def test_init_non_interactive(project_no_init, invoke, mocker):
         author="Testing",
         email="me@example.org",
         python_requires=f">={python_version}",
+        build_backend=None,
         hooks=ANY,
     )
 
@@ -103,6 +109,21 @@ def test_init_auto_create_venv(project_no_init, invoke, mocker):
     )
 
 
+def test_init_auto_create_venv_specify_python(project_no_init, invoke, mocker):
+    mocker.patch("pdm.cli.commands.init.get_venv_like_prefix", return_value=None)
+    project_no_init.project_config["python.use_venv"] = True
+    result = invoke(
+        ["init", f"--python={PYTHON_VERSION}"],
+        input="\n\n\n\n\n\n",
+        obj=project_no_init,
+    )
+    assert result.exit_code == 0
+    assert (
+        project_no_init.python.executable.parent.parent
+        == project_no_init.root / ".venv"
+    )
+
+
 def test_init_auto_create_venv_answer_no(project_no_init, invoke, mocker):
     mocker.patch("pdm.cli.commands.init.get_venv_like_prefix", return_value=None)
     creator = mocker.patch("pdm.cli.commands.venv.backends.Backend.create")
